@@ -95,9 +95,9 @@ def _format(response):
     elif response['status'] == 'rejected':
         id_error = int(response['status_details']['error']['reason']['id'])
         if id_error in map_errors:
-            response['status_detail'] = map_errors[response[id_error]]
+            response['status_detail'] = map_errors[id_error]
         else:
-            response['status_detail'] = 'ERROR DESCONOCIDO'
+            response['status_detail'] = 'error desconocido'
 
     date = parse_date(response['date']).astimezone(arg_tz)
     result = {
@@ -177,10 +177,10 @@ class Payment(MuviBase):
         # Se genera la request
         r = requests.post(self.url + '/payments', headers=self.headers, json=body)
         response = r.json()
-        if r.status_code < 400:
+        if 'status' in response and 'site_transaction_id' in response:
             if 'card' in payment_data:
                 response['card'] = payment_data['card']
-            return self.ok(_format(response), status=r.status_code)
+            return self.ok(_format(response))
         return self.error(response, status=r.status_code)
 
     def get(self, payment_id: str):
